@@ -46,9 +46,13 @@ bool Archive::GetComment(Array<byte> *CmtData,Array<wchar> *CmtDataW)
     uint UnpCmtLength;
     if (OldFormat)
     {
+#ifdef NOCRYPT
+      return(false);
+#else
       UnpCmtLength=GetByte()+(GetByte()<<8);
       CmtLength-=2;
       DataIO.SetCmt13Encryption();
+#endif
     }
     else
       UnpCmtLength=CommHead.UnpSize;
